All of lore.kernel.org
 help / color / mirror / Atom feed
From: mhagger@alum.mit.edu
To: Junio C Hamano <gitster@pobox.com>
Cc: git@vger.kernel.org, Jeff King <peff@peff.net>,
	Jakub Narebski <jnareb@gmail.com>,
	Heiko Voigt <hvoigt@hvoigt.net>,
	Johan Herland <johan@herland.net>,
	Michael Haggerty <mhagger@alum.mit.edu>
Subject: [PATCH 23/30] do_for_each_ref_in_dirs(): take (ref_entry *) instead of (ref_dir *)
Date: Wed, 25 Apr 2012 00:45:29 +0200	[thread overview]
Message-ID: <1335307536-26914-24-git-send-email-mhagger@alum.mit.edu> (raw)
In-Reply-To: <1335307536-26914-1-git-send-email-mhagger@alum.mit.edu>

From: Michael Haggerty <mhagger@alum.mit.edu>


Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu>
---
 refs.c |   48 +++++++++++++++++++++++++-----------------------
 1 file changed, 25 insertions(+), 23 deletions(-)

diff --git a/refs.c b/refs.c
index a794d3a..4448b14 100644
--- a/refs.c
+++ b/refs.c
@@ -468,35 +468,38 @@ static int do_for_each_ref_in_dir(struct ref_dir *dir, int offset,
 }
 
 /*
  * Call fn for each reference in the union of dir1 and dir2, in order
  * by refname.  Recurse into subdirectories.  If a value entry appears
  * in both dir1 and dir2, then only process the version that is in
  * dir2.  The input dirs must already be sorted, but subdirs will be
  * sorted as needed.
  */
-static int do_for_each_ref_in_dirs(struct ref_dir *dir1,
-				   struct ref_dir *dir2,
+static int do_for_each_ref_in_dirs(struct ref_entry *direntry1,
+				   struct ref_entry *direntry2,
 				   const char *base, each_ref_fn fn, int trim,
 				   int flags, void *cb_data)
 {
 	int retval;
 	int i1 = 0, i2 = 0;
 
-	assert(dir1->sorted == dir1->nr);
-	assert(dir2->sorted == dir2->nr);
+	assert(direntry1->flag & REF_DIR);
+	assert(direntry2->flag & REF_DIR);
+	assert(direntry1->u.subdir.sorted == direntry1->u.subdir.nr);
+	assert(direntry2->u.subdir.sorted == direntry2->u.subdir.nr);
+
 	while (1) {
 		struct ref_entry *e1, *e2;
 		int cmp;
-		if (i1 == dir1->nr) {
-			return do_for_each_ref_in_dir(dir2, i2,
+		if (i1 == direntry1->u.subdir.nr) {
+			return do_for_each_ref_in_dir(&direntry2->u.subdir, i2,
 						      base, fn, trim, flags, cb_data);
 		}
-		if (i2 == dir2->nr) {
-			return do_for_each_ref_in_dir(dir1, i1,
+		if (i2 == direntry2->u.subdir.nr) {
+			return do_for_each_ref_in_dir(&direntry1->u.subdir, i1,
 						      base, fn, trim, flags, cb_data);
 		}
-		e1 = dir1->entries[i1];
-		e2 = dir2->entries[i2];
+		e1 = direntry1->u.subdir.entries[i1];
+		e2 = direntry2->u.subdir.entries[i2];
 		cmp = strcmp(e1->name, e2->name);
 		if (cmp == 0) {
 			if ((e1->flag & REF_DIR) && (e2->flag & REF_DIR)) {
@@ -504,12 +507,12 @@ static int do_for_each_ref_in_dirs(struct ref_dir *dir1,
 				sort_ref_dir(&e1->u.subdir);
 				sort_ref_dir(&e2->u.subdir);
 				retval = do_for_each_ref_in_dirs(
-						&e1->u.subdir, &e2->u.subdir,
+						e1, e2,
 						base, fn, trim, flags, cb_data);
 				i1++;
 				i2++;
 			} else if (!(e1->flag & REF_DIR) && !(e2->flag & REF_DIR)) {
 				/* Both are references; ignore the one from dir1. */
 				retval = do_one_ref(base, fn, trim, flags, cb_data, e2);
 				i1++;
 				i2++;
@@ -538,11 +541,11 @@ static int do_for_each_ref_in_dirs(struct ref_dir *dir1,
 		if (retval)
 			return retval;
 	}
-	if (i1 < dir1->nr)
-		return do_for_each_ref_in_dir(dir1, i1,
+	if (i1 < direntry1->u.subdir.nr)
+		return do_for_each_ref_in_dir(&direntry1->u.subdir, i1,
 					      base, fn, trim, flags, cb_data);
-	if (i2 < dir2->nr)
-		return do_for_each_ref_in_dir(dir2, i2,
+	if (i2 < direntry2->u.subdir.nr)
+		return do_for_each_ref_in_dir(&direntry2->u.subdir, i2,
 					      base, fn, trim, flags, cb_data);
 	return 0;
 }
@@ -1186,8 +1189,7 @@ static int do_for_each_ref(const char *submodule, const char *base, each_ref_fn
 		sort_ref_dir(&packed_direntry->u.subdir);
 		sort_ref_dir(&loose_direntry->u.subdir);
 		retval = do_for_each_ref_in_dirs(
-				&packed_direntry->u.subdir,
-				&loose_direntry->u.subdir,
+				packed_direntry, loose_direntry,
 				base, fn, trim, flags, cb_data);
 	} else if (packed_direntry) {
 		sort_ref_dir(&packed_direntry->u.subdir);
@@ -468,35 +468,38 @@ static int do_for_each_ref_in_dir(struct ref_dir *dir, int offset,
 
 /*
- * Call fn for each reference in the union of dir1 and dir2, in order
- * by refname.  Recurse into subdirectories.  If a value entry appears
- * in both dir1 and dir2, then only process the version that is in
- * dir2.  The input dirs must already be sorted, but subdirs will be
- * sorted as needed.
+ * Call fn for each reference in the union of direntry1 and direntry2,
+ * in order by refname.  Recurse into subdirectories.  If a value
+ * entry appears in both direntry1 and direntry2, then only process
+ * the version that is in direntry2.  The input direntries must
+ * already be sorted, but subdirs will be sorted as needed.
  */
@@ -504,12 +507,12 @@ static int do_for_each_ref_in_dirs(struct ref_dir *dir1,
 				i2++;
 			} else if (!(e1->flag & REF_DIR) && !(e2->flag & REF_DIR)) {
-				/* Both are references; ignore the one from dir1. */
+				/* Both are references; ignore the one from direntry1. */
 				retval = do_one_ref(base, fn, trim, flags, cb_data, e2);
 				i1++;
-- 
1.7.10

  parent reply	other threads:[~2012-04-24 22:57 UTC|newest]

Thread overview: 37+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2012-04-24 22:45 [PATCH 00/30] Read loose references lazily mhagger
2012-04-24 22:45 ` [PATCH 01/30] get_ref_dir(): return early if directory cannot be read mhagger
2012-04-24 22:45 ` [PATCH 02/30] get_ref_dir(): use a strbuf to hold refname mhagger
2012-04-24 22:45 ` [PATCH 03/30] get_ref_dir(): rename "base" parameter to "dirname" mhagger
2012-04-24 22:45 ` [PATCH 04/30] get_ref_dir(): require that the dirname argument ends in '/' mhagger
2012-04-24 22:45 ` [PATCH 05/30] refs.c: extract function search_for_subdir() mhagger
2012-04-24 22:45 ` [PATCH 06/30] get_ref_dir(): take the containing directory as argument mhagger
2012-04-24 22:45 ` [PATCH 07/30] do_for_each_reflog(): return early on error mhagger
2012-04-24 22:45 ` [PATCH 08/30] do_for_each_reflog(): use a strbuf to hold logfile name mhagger
2012-04-24 22:45 ` [PATCH 09/30] do_for_each_reflog(): reuse strbuf across recursive function calls mhagger
2012-04-24 22:45 ` [PATCH 10/30] refs: wrap top-level ref_dirs in ref_entries mhagger
2012-04-26 14:38   ` Michael Haggerty
2012-04-24 22:45 ` [PATCH 11/30] get_packed_refs(): return (ref_entry *) instead of (ref_dir *) mhagger
2012-04-24 22:45 ` [PATCH 12/30] get_loose_refs(): " mhagger
2012-04-24 22:45 ` [PATCH 13/30] is_refname_available(): take " mhagger
2012-04-24 22:45 ` [PATCH 14/30] find_ref(): " mhagger
2012-04-24 22:45 ` [PATCH 15/30] read_packed_refs(): " mhagger
2012-04-24 22:45 ` [PATCH 16/30] add_ref(): " mhagger
2012-04-24 22:45 ` [PATCH 17/30] find_containing_direntry(): use " mhagger
2012-04-24 22:45 ` [PATCH 18/30] get_ref_dir(): take " mhagger
2012-04-24 22:45 ` [PATCH 19/30] get_ref_dir(): remove dirname argument mhagger
2012-04-24 22:45 ` [PATCH 20/30] search_for_subdir(): take (ref_entry *) instead of (ref_dir *) mhagger
2012-04-24 22:45 ` [PATCH 21/30] search_ref_dir(): " mhagger
2012-04-24 22:45 ` [PATCH 22/30] add_entry(): " mhagger
2012-04-24 22:45 ` mhagger [this message]
2012-04-24 22:45 ` [PATCH 24/30] do_for_each_ref_in_dir(): " mhagger
2012-04-24 22:45 ` [PATCH 25/30] sort_ref_dir(): " mhagger
2012-04-24 22:45 ` [PATCH 26/30] struct ref_dir: store a reference to the enclosing ref_cache mhagger
2012-04-24 22:45 ` [PATCH 27/30] read_loose_refs(): rename function from get_ref_dir() mhagger
2012-04-24 22:45 ` [PATCH 28/30] read_loose_refs(): access ref_cache via the ref_dir field mhagger
2012-04-24 22:45 ` [PATCH 29/30] create_dir_entry(): allow the flag value to be passed as an argument mhagger
2012-04-25 18:31   ` Junio C Hamano
2012-04-25 18:52     ` Junio C Hamano
2012-04-26 21:12       ` Michael Haggerty
2012-04-24 22:45 ` [PATCH 30/30] refs: read loose references lazily mhagger
2012-04-25 18:39 ` [PATCH 00/30] Read " Junio C Hamano
2012-04-26 21:33   ` Michael Haggerty

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1335307536-26914-24-git-send-email-mhagger@alum.mit.edu \
    --to=mhagger@alum.mit.edu \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=hvoigt@hvoigt.net \
    --cc=jnareb@gmail.com \
    --cc=johan@herland.net \
    --cc=peff@peff.net \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.